util

package
v0.0.0-...-a5f8858 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 27, 2025 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Bool

func Bool(val string) (bool, error)

func BoolSlice

func BoolSlice(val, sep string) ([]bool, error)

func BoolValue

func BoolValue(val string) (*wrapperspb.BoolValue, error)

func Bytes

func Bytes(val string) ([]byte, error)

func BytesSlice

func BytesSlice(val, sep string) ([][]byte, error)

func BytesValue

func BytesValue(val string) (*wrapperspb.BytesValue, error)

func DoubleValue

func DoubleValue(val string) (*wrapperspb.DoubleValue, error)

func Duration

func Duration(val string) (*durationpb.Duration, error)

func Enum

func Enum(val string, enumValMap map[string]int32) (int32, error)

func EnumSlice

func EnumSlice(val, sep string, enumValMap map[string]int32) ([]int32, error)

func Float32

func Float32(val string) (float32, error)

func Float32Slice

func Float32Slice(val, sep string) ([]float32, error)

func Float64

func Float64(val string) (float64, error)

func Float64Slice

func Float64Slice(val, sep string) ([]float64, error)

func FloatValue

func FloatValue(val string) (*wrapperspb.FloatValue, error)

func Int32

func Int32(val string) (int32, error)

func Int32Slice

func Int32Slice(val, sep string) ([]int32, error)

func Int32Value

func Int32Value(val string) (*wrapperspb.Int32Value, error)

func Int64

func Int64(val string) (int64, error)

Int64 converts the given string representation of an integer into int64.

func Int64Slice

func Int64Slice(val, sep string) ([]int64, error)

func Int64Value

func Int64Value(val string) (*wrapperspb.Int64Value, error)

func String

func String(val string) (string, error)

func StringSlice

func StringSlice(val, sep string) ([]string, error)

func StringValue

func StringValue(val string) (*wrapperspb.StringValue, error)

func Timestamp

func Timestamp(val string) (*timestamppb.Timestamp, error)

func UInt32Value

func UInt32Value(val string) (*wrapperspb.UInt32Value, error)

func UInt64Value

func UInt64Value(val string) (*wrapperspb.UInt64Value, error)

func Uint32

func Uint32(val string) (uint32, error)

Uint32 converts the given string representation of an integer into uint32.

func Uint32Slice

func Uint32Slice(val, sep string) ([]uint32, error)

func Uint64

func Uint64(val string) (uint64, error)

func Uint64Slice

func Uint64Slice(val, sep string) ([]uint64, error)

Uint64Slice converts 'val' where individual integers are separated by 'sep' into a uint64 slice.

Types

This section is empty.

Jump to